evrmail --help

evrmail outbox set <owned_asset>

evrmail outbox get

evrmail inbox open

evrmail inbox list

evrmail inbox unread

evrmail compose

evrmail daemon start

evrmail daemon stop

evrmail ipfs install

evrmail ipfs uninstall

evrmail ipfs start 

evrmail ipfs stop

More info coming soon!

